@@ -314,7 +314,7 @@ class _FeatureStoreModelWrapper:
                         f"table {ft_name}, but found {feature_values_df.shape[0]}"
                     )
 
-                # If any features were partially overriden, use the override values.
+                # If any features were partially overridden, use the override values.
                 # Filter all partially overridden feature output names down to those that
                 # are in the feature table currently being processed.
                 partially_overridden_feats = [
@@ -322,16 +322,16 @@ class _FeatureStoreModelWrapper:
                     for c in feature_values_df.columns
                     if c in partially_overridden_feature_output_names
                 ]
-                with_partial_overrides = feature_values_df.combine(
-                    df[partially_overridden_feats],
+                if partially_overridden_feats:
                     # For each cell of overridden column, use the overridden value if provided, else
                     # the value looked up from the online store.
-                    lambda online_store_col, override_col: override_col.combine_first(
-                        online_store_col
-                    ),
-                )
-
-                feature_dfs.append(with_partial_overrides)
+                    partially_overridden_feats_df = df[
+                        partially_overridden_feats
+                    ].combine_first(feature_values_df[partially_overridden_feats])
+                    feature_values_df[
+                        partially_overridden_feats
+                    ] = partially_overridden_feats_df[partially_overridden_feats]
+                feature_dfs.append(feature_values_df)
 
         # Include inputs from provided DataFrame
         source_data_df = df[
